@@ -16,14 +16,19 @@ class PreCheck:
             self.user_id = server_config["user_id"]
             self.user_password = server_config["user_password"]
             self.project_name = server_config["project_name"]
-            self.train_input_columns = image_config["train_input_columns"]
             self.train_do_name = server_config["train_do_name"]
-            self.inference_input_columns = image_config["inference_input_columns"]
             self.inference_do_name = server_config["inference_do_name"]
         except KeyError as e:
             print(f'Cannot found "{str(e)}" in server_config.yaml')
             exit(1)
 
+        try:
+            self.train_input_columns = image_config["train"]["train_input_columns"]
+            self.inference_input_columns = image_config["train"]["inference_input_columns"]
+        except KeyError as e:
+            print(f'Cannot found "{str(e)}" in image_config.yaml')
+            exit(1)
+
         self.hyperdata_client = HyperdataHttpClient(self.hyperdata_addr)
 
     def _print_header(self, msg: str):
